@@ -6,15 +6,16 @@ from typing import Tuple, List
 
 import numpy as np
 
+from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.enum_types import (DwfTriggerLengthCondition, DwfTriggerSource, DwfTriggerType,
                                              DwfTriggerSlope, DwfAnalogInFilter, DwfAcquisitionMode, DwfState)
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.exceptions import PyDwfError
-from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
-class AnalogIn(DwfDevice_SubAPI):
+class AnalogIn(DwfDeviceSubApi):
     """The |AnalogIn| class provides access to the AnalogIn (oscilloscope) instrument of a |DwfDevice:link|.
 
     Attention:
