@@ -4,13 +4,14 @@ import ctypes
 
 from typing import Tuple
 
+from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.enum_types import DwfAnalogIO
-from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
-class AnalogIO(DwfDevice_SubAPI):
+class AnalogIO(DwfDeviceSubApi):
     """The |AnalogIO| class provides access to the analog I/O functionality of a |DwfDevice:link|.
 
     The |AnalogIO| methods are used to control the power supplies, reference voltage supplies, voltmeters, ammeters,
