@@ -1,17 +1,20 @@
 """The |pydwf.core.api.analog_out| module implements a single class: |AnalogOut|."""
 
+# pylint: disable=too-many-lines
+
 from typing import Tuple, List
 
 import numpy as np
 
+from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.enum_types import (DwfTriggerSource, DwfAnalogOutFunction, DwfState,
                                              DwfAnalogOutNode, DwfTriggerSlope, DwfAnalogOutMode, DwfAnalogOutIdle)
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
-from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
-class AnalogOut(DwfDevice_SubAPI):
+class AnalogOut(DwfDeviceSubApi):
     """The |AnalogOut| class provides access to the AnalogOut (signal generator) instrument of a |DwfDevice:link|.
 
     Attention:
@@ -23,8 +26,45 @@ class AnalogOut(DwfDevice_SubAPI):
 
     # pylint: disable=too-many-public-methods
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               INSTRUMENT CONTROL                                                 #
+    #                                                                                                                  #
+    ####################################################################################################################
+
+    def reset(self, channel_index: int) -> None:
+        """Reset the AnalogOut instrument.
+        """
+        result = self.lib.FDwfAnalogOutReset(self.hdwf, channel_index)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def configure(self, channel_index: int, start: bool) -> None:
+        """Configure the AnalogOut instrument.
+        """
+        result = self.lib.FDwfAnalogOutConfigure(self.hdwf, channel_index, start)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def status(self, channel_index: int) -> DwfState:
+        """Get AnalogOut instrument state.
+        """
+        c_status = typespec_ctypes.DwfState()
+        result = self.lib.FDwfAnalogOutStatus(self.hdwf, channel_index, c_status)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        status = DwfState(c_status.value)
+        return status
+
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                                    CHANNEL COUNT                                                 #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def count(self) -> int:
-        """Count number of analog output channels."""
+        """Count number of analog output channels.
+        """
         c_cChannel = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogOutCount(self.hdwf, c_cChannel)
         if result != RESULT_SUCCESS:
@@ -32,14 +72,22 @@ class AnalogOut(DwfDevice_SubAPI):
         cChannel = c_cChannel.value
         return cChannel
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               PER-CHANNEL CONFIGURATION                                          #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def masterSet(self, channel_index: int, master_index: int) -> None:
-        """Set master status."""
+        """Set master status.
+        """
         result = self.lib.FDwfAnalogOutMasterSet(self.hdwf, channel_index, master_index)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def masterGet(self, channel_index: int) -> int:
-        """Get master status."""
+        """Get master status.
+        """
         c_master_index = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogOutMasterGet(self.hdwf, channel_index, c_master_index)
         if result != RESULT_SUCCESS:
@@ -47,44 +95,54 @@ class AnalogOut(DwfDevice_SubAPI):
         master_index = c_master_index.value
         return master_index
 
-    def triggerSourceSet(self, channel_index: int, trigger_source: DwfTriggerSource) -> None:
-        """Set trigger source."""
-        result = self.lib.FDwfAnalogOutTriggerSourceSet(
-            self.hdwf,
-            channel_index,
-            trigger_source.value)
+    def modeSet(self, channel_index: int, mode: DwfAnalogOutMode) -> None:
+        """Set analog output mode.
+        """
+        result = self.lib.FDwfAnalogOutModeSet(self.hdwf, channel_index, mode.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerSourceGet(self, channel_index: int) -> DwfTriggerSource:
-        """Get trigger source."""
-        c_trigger_source = typespec_ctypes.TRIGSRC()
-        result = self.lib.FDwfAnalogOutTriggerSourceGet(self.hdwf, channel_index, c_trigger_source)
+    def modeGet(self, channel_index: int) -> DwfAnalogOutMode:
+        """Get analog output mode.
+        """
+        c_mode = typespec_ctypes.DwfAnalogOutMode()
+        result = self.lib.FDwfAnalogOutModeGet(self.hdwf, channel_index, c_mode)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_source = DwfTriggerSource(c_trigger_source.value)
-        return trigger_source
+        mode = DwfAnalogOutMode(c_mode.value)
+        return mode
 
-    def triggerSlopeSet(self, channel_index: int, trigger_slope: DwfTriggerSlope) -> None:
-        """Set trigger slope."""
-        result = self.lib.FDwfAnalogOutTriggerSlopeSet(
-            self.hdwf,
-            channel_index,
-            trigger_slope.value)
+    def idleInfo(self, channel_index: int) -> List[DwfAnalogOutIdle]:
+        """Get idle info.
+        """
+        c_idle_bitset = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogOutIdleInfo(self.hdwf, channel_index, c_idle_bitset)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        idle_bitset = c_idle_bitset.value
+        idle_list = [idle for idle in DwfAnalogOutIdle if idle_bitset & (1 << idle.value)]
+        return idle_list
+
+    def idleSet(self, channel_index: int, idle: DwfAnalogOutIdle) -> None:
+        """Set idle behavior.
+        """
+        result = self.lib.FDwfAnalogOutIdleSet(self.hdwf, channel_index, idle.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerSlopeGet(self, channel_index: int) -> DwfTriggerSlope:
-        """Get trigger slope."""
-        c_trigger_slope = typespec_ctypes.DwfTriggerSlope()
-        result = self.lib.FDwfAnalogOutTriggerSlopeGet(self.hdwf, channel_index, c_trigger_slope)
+    def idleGet(self, channel_index: int) -> DwfAnalogOutIdle:
+        """Get idle behavior.
+        """
+        c_idle = typespec_ctypes.DwfAnalogOutIdle()
+        result = self.lib.FDwfAnalogOutIdleGet(self.hdwf, channel_index, c_idle)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_slope = DwfTriggerSlope(c_trigger_slope.value)
-        return trigger_slope
+        idle = DwfAnalogOutIdle(c_idle.value)
+        return idle
 
     def runInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get run info."""
+        """Get run info.
+        """
         c_secMin = typespec_ctypes.c_double()
         c_secMax = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutRunInfo(self.hdwf, channel_index, c_secMin, c_secMax)
@@ -95,13 +153,15 @@ class AnalogOut(DwfDevice_SubAPI):
         return (secMin, secMax)
 
     def runSet(self, channel_index: int, run_duration: float) -> None:
-        """Set run duration, in seconds."""
+        """Set run duration, in seconds.
+        """
         result = self.lib.FDwfAnalogOutRunSet(self.hdwf, channel_index, run_duration)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def runGet(self, channel_index: int) -> float:
-        """Get run-time."""
+        """Get run-time.
+        """
         c_run_duration = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutRunGet(self.hdwf, channel_index, c_run_duration)
         if result != RESULT_SUCCESS:
@@ -110,7 +170,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return run_duration
 
     def runStatus(self, channel_index: int) -> float:
-        """Get run status."""
+        """Get run status.
+        """
         c_secRun = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutRunStatus(self.hdwf, channel_index, c_secRun)
         if result != RESULT_SUCCESS:
@@ -119,7 +180,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return secRun
 
     def waitInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get wait info."""
+        """Get wait info.
+        """
         c_secMin = typespec_ctypes.c_double()
         c_secMax = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutWaitInfo(self.hdwf, channel_index, c_secMin, c_secMax)
@@ -130,13 +192,15 @@ class AnalogOut(DwfDevice_SubAPI):
         return (secMin, secMax)
 
     def waitSet(self, channel_index: int, wait_duration: float) -> None:
-        """Set wait state duration, in seconds."""
+        """Set wait state duration, in seconds.
+        """
         result = self.lib.FDwfAnalogOutWaitSet(self.hdwf, channel_index, wait_duration)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def waitGet(self, channel_index: int) -> float:
-        """Get wait state duration in seconds."""
+        """Get wait state duration in seconds.
+        """
         c_wait_duration = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutWaitGet(self.hdwf, channel_index, c_wait_duration)
         if result != RESULT_SUCCESS:
@@ -145,7 +209,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return wait_duration
 
     def repeatInfo(self, channel_index: int) -> Tuple[int, int]:
-        """Get repeat info."""
+        """Get repeat info.
+        """
         c_nMin = typespec_ctypes.c_int()
         c_nMax = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogOutRepeatInfo(self.hdwf, channel_index, c_nMin, c_nMax)
@@ -156,13 +221,15 @@ class AnalogOut(DwfDevice_SubAPI):
         return (nMin, nMax)
 
     def repeatSet(self, channel_index: int, repeat: int) -> None:
-        """Set repeat setting."""
+        """Set repeat setting.
+        """
         result = self.lib.FDwfAnalogOutRepeatSet(self.hdwf, channel_index, repeat)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def repeatGet(self, channel_index: int) -> int:
-        """Get repeat setting."""
+        """Get repeat setting.
+        """
         c_repeat = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogOutRepeatGet(self.hdwf, channel_index, c_repeat)
         if result != RESULT_SUCCESS:
@@ -171,7 +238,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return repeat
 
     def repeatStatus(self, channel_index: int) -> int:
-        """Get repeat status."""
+        """Get repeat status.
+        """
         c_repeat_status = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogOutRepeatStatus(self.hdwf, channel_index, c_repeat_status)
         if result != RESULT_SUCCESS:
@@ -180,13 +248,15 @@ class AnalogOut(DwfDevice_SubAPI):
         return repeat_status
 
     def repeatTriggerSet(self, channel_index: int, repeat_trigger_flag: bool) -> None:
-        """Set repeat trigger setting."""
+        """Set repeat trigger setting.
+        """
         result = self.lib.FDwfAnalogOutRepeatTriggerSet(self.hdwf, channel_index, repeat_trigger_flag)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def repeatTriggerGet(self, channel_index: int) -> bool:
-        """Get repeat trigger setting."""
+        """Get repeat trigger setting.
+        """
         c_repeat_trigger_flag = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogOutRepeatTriggerGet(
             self.hdwf,
@@ -198,7 +268,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return repeat_trigger_flag
 
     def limitationInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get limitation info."""
+        """Get limitation info.
+        """
         c_min = typespec_ctypes.c_double()
         c_max = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutLimitationInfo(self.hdwf, channel_index, c_min, c_max)
@@ -209,13 +280,15 @@ class AnalogOut(DwfDevice_SubAPI):
         return (min_, max_)
 
     def limitationSet(self, channel_index: int, limit: float) -> None:
-        """Set limitation value."""
+        """Set limitation value.
+        """
         result = self.lib.FDwfAnalogOutLimitationSet(self.hdwf, channel_index, limit)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def limitationGet(self, channel_index: int) -> float:
-        """Get limitation value."""
+        """Get limitation value.
+        """
         c_limit = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutLimitationGet(self.hdwf, channel_index, c_limit)
         if result != RESULT_SUCCESS:
@@ -223,48 +296,92 @@ class AnalogOut(DwfDevice_SubAPI):
         limit = c_limit.value
         return limit
 
-    def modeSet(self, channel_index: int, mode: DwfAnalogOutMode) -> None:
-        """Set analog output mode."""
-        result = self.lib.FDwfAnalogOutModeSet(self.hdwf, channel_index, mode.value)
+    def customAMFMEnableSet(self, channel_index: int, enable: bool) -> None:
+        """Set custom AM/FM enable status.
+        """
+        result = self.lib.FDwfAnalogOutCustomAMFMEnableSet(self.hdwf, channel_index, int(enable))
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def modeGet(self, channel_index: int) -> DwfAnalogOutMode:
-        """Get analog output mode."""
-        c_mode = typespec_ctypes.DwfAnalogOutMode()
-        result = self.lib.FDwfAnalogOutModeGet(self.hdwf, channel_index, c_mode)
+    def customAMFMEnableGet(self, channel_index: int) -> bool:
+        """Get custom AM/FM enable status.
+        """
+        c_enable = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogOutCustomAMFMEnableGet(self.hdwf, channel_index, c_enable)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        mode = DwfAnalogOutMode(c_mode.value)
-        return mode
+        enable = bool(c_enable.value)
+        return enable
 
-    def idleInfo(self, channel_index: int) -> List[DwfAnalogOutIdle]:
-        """Get idle info."""
-        c_idle_bitset = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogOutIdleInfo(self.hdwf, channel_index, c_idle_bitset)
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                           PER-CHANNEL TRIGGER CONFIGURATION                                      #
+    #                                                                                                                  #
+    ####################################################################################################################
+
+    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
+        """Get analog out trigger source info.
+
+        This function is OBSOLETE.
+        """
+        c_trigger_source_info_bitset = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogOutTriggerSourceInfo(self.hdwf, c_trigger_source_info_bitset)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        idle_bitset = c_idle_bitset.value
-        idle_list = [idle for idle in DwfAnalogOutIdle if idle_bitset & (1 << idle.value)]
-        return idle_list
+        trigger_source_info_bitset = c_trigger_source_info_bitset.value
+        trigger_source_info_list = [trigger_source for trigger_source in DwfTriggerSource
+                                    if trigger_source_info_bitset & (1 << trigger_source.value)]
+        return trigger_source_info_list
 
-    def idleSet(self, channel_index: int, idle: DwfAnalogOutIdle) -> None:
-        """Set idle behavior."""
-        result = self.lib.FDwfAnalogOutIdleSet(self.hdwf, channel_index, idle.value)
+    def triggerSourceSet(self, channel_index: int, trigger_source: DwfTriggerSource) -> None:
+        """Set trigger source.
+        """
+        result = self.lib.FDwfAnalogOutTriggerSourceSet(
+            self.hdwf,
+            channel_index,
+            trigger_source.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def idleGet(self, channel_index: int) -> DwfAnalogOutIdle:
-        """Get idle behavior."""
-        c_idle = typespec_ctypes.DwfAnalogOutIdle()
-        result = self.lib.FDwfAnalogOutIdleGet(self.hdwf, channel_index, c_idle)
+    def triggerSourceGet(self, channel_index: int) -> DwfTriggerSource:
+        """Get trigger source.
+        """
+        c_trigger_source = typespec_ctypes.TRIGSRC()
+        result = self.lib.FDwfAnalogOutTriggerSourceGet(self.hdwf, channel_index, c_trigger_source)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        idle = DwfAnalogOutIdle(c_idle.value)
-        return idle
+        trigger_source = DwfTriggerSource(c_trigger_source.value)
+        return trigger_source
+
+    def triggerSlopeSet(self, channel_index: int, trigger_slope: DwfTriggerSlope) -> None:
+        """Set trigger slope.
+        """
+        result = self.lib.FDwfAnalogOutTriggerSlopeSet(
+            self.hdwf,
+            channel_index,
+            trigger_slope.value)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def triggerSlopeGet(self, channel_index: int) -> DwfTriggerSlope:
+        """Get trigger slope.
+        """
+        c_trigger_slope = typespec_ctypes.DwfTriggerSlope()
+        result = self.lib.FDwfAnalogOutTriggerSlopeGet(self.hdwf, channel_index, c_trigger_slope)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        trigger_slope = DwfTriggerSlope(c_trigger_slope.value)
+        return trigger_slope
+
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                                  NODE ENUMERATION                                                #
+    #                                                                                                                  #
+    ####################################################################################################################
 
     def nodeInfo(self, channel_index: int) -> List[DwfAnalogOutNode]:
-        """Get node info."""
+        """Get node info.
+        """
         c_node_info_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogOutNodeInfo(self.hdwf, channel_index, c_node_info_bitset)
         if result != RESULT_SUCCESS:
@@ -273,8 +390,15 @@ class AnalogOut(DwfDevice_SubAPI):
         node_info_list = [node for node in DwfAnalogOutNode if node_info_bitset & (1 << node.value)]
         return node_info_list
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                                  NODE CONFIGURATION                                              #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def nodeEnableSet(self, channel_index: int, node: DwfAnalogOutNode, enable: bool) -> None:
-        """Set node enabled state."""
+        """Set node enabled state.
+        """
         result = self.lib.FDwfAnalogOutNodeEnableSet(self.hdwf, channel_index, node.value, enable)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
@@ -289,7 +413,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return enable
 
     def nodeFunctionInfo(self, channel_index: int, node: DwfAnalogOutNode) -> List[DwfAnalogOutFunction]:
-        """Get node function info."""
+        """Get node function info.
+        """
         c_func_bitset = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfAnalogOutNodeFunctionInfo(
             self.hdwf,
@@ -309,7 +434,8 @@ class AnalogOut(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def nodeFunctionGet(self, channel_index: int, node: DwfAnalogOutNode) -> DwfAnalogOutFunction:
-        """Get node function."""
+        """Get node function.
+        """
         c_func = typespec_ctypes.FUNC()
         result = self.lib.FDwfAnalogOutNodeFunctionGet(self.hdwf, channel_index, node.value, c_func)
         if result != RESULT_SUCCESS:
@@ -318,7 +444,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return func
 
     def nodeFrequencyInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get node frequency info, in Hz."""
+        """Get node frequency info, in Hz.
+        """
         c_frequency_min = typespec_ctypes.c_double()
         c_frequency_max = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutNodeFrequencyInfo(
@@ -334,7 +461,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return (frequency_min, frequency_max)
 
     def nodeFrequencySet(self, channel_index: int, node: DwfAnalogOutNode, frequency: float) -> None:
-        """Set node frequency, in Hz."""
+        """Set node frequency, in Hz.
+        """
         result = self.lib.FDwfAnalogOutNodeFrequencySet(
             self.hdwf,
             channel_index,
@@ -344,7 +472,8 @@ class AnalogOut(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def nodeFrequencyGet(self, channel_index: int, node: DwfAnalogOutNode) -> float:
-        """Get node frequency, in Hz."""
+        """Get node frequency, in Hz.
+        """
         c_frequency = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutNodeFrequencyGet(
             self.hdwf,
@@ -357,7 +486,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return frequency
 
     def nodeAmplitudeInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get node amplitude info, in Volts."""
+        """Get node amplitude info, in Volts.
+        """
         c_amplitude_min = typespec_ctypes.c_double()
         c_amplitude_max = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutNodeAmplitudeInfo(
@@ -373,7 +503,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return (amplitude_min, amplitude_max)
 
     def nodeAmplitudeSet(self, channel_index: int, node: DwfAnalogOutNode, amplitude: float) -> None:
-        """Set node amplitude, in Volts."""
+        """Set node amplitude, in Volts.
+        """
         result = self.lib.FDwfAnalogOutNodeAmplitudeSet(
             self.hdwf,
             channel_index,
@@ -383,7 +514,8 @@ class AnalogOut(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def nodeAmplitudeGet(self, channel_index: int, node: DwfAnalogOutNode) -> float:
-        """Get node amplitude, in Volts."""
+        """Get node amplitude, in Volts.
+        """
         c_amplitude = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutNodeAmplitudeGet(
             self.hdwf,
@@ -396,7 +528,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return amplitude
 
     def nodeOffsetInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get node offset info, in Volts."""
+        """Get node offset info, in Volts.
+        """
         c_offset_min = typespec_ctypes.c_double()
         c_offset_max = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutNodeOffsetInfo(self.hdwf, channel_index, node.value, c_offset_min, c_offset_max)
@@ -407,13 +540,15 @@ class AnalogOut(DwfDevice_SubAPI):
         return (offset_min, offset_max)
 
     def nodeOffsetSet(self, channel_index: int, node: DwfAnalogOutNode, offset: float) -> None:
-        """Set node offset, in Volts."""
+        """Set node offset, in Volts.
+        """
         result = self.lib.FDwfAnalogOutNodeOffsetSet(self.hdwf, channel_index, node.value, offset)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def nodeOffsetGet(self, channel_index: int, node: DwfAnalogOutNode) -> float:
-        """Get node offset, in Volts."""
+        """Get node offset, in Volts.
+        """
         c_offset = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutNodeOffsetGet(self.hdwf, channel_index, node.value, c_offset)
         if result != RESULT_SUCCESS:
@@ -422,7 +557,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return offset
 
     def nodeSymmetryInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get node symmetry info."""
+        """Get node symmetry info.
+        """
         c_symmetry_min = typespec_ctypes.c_double()
         c_symmetry_max = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutNodeSymmetryInfo(
@@ -438,7 +574,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return (symmetry_min, symmetry_max)
 
     def nodeSymmetrySet(self, channel_index: int, node: DwfAnalogOutNode, symmetry: float) -> None:
-        """Set node symmetry."""
+        """Set node symmetry.
+        """
         result = self.lib.FDwfAnalogOutNodeSymmetrySet(
             self.hdwf,
             channel_index,
@@ -448,7 +585,8 @@ class AnalogOut(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def nodeSymmetryGet(self, channel_index: int, node: DwfAnalogOutNode) -> float:
-        """Get node symmetry."""
+        """Get node symmetry.
+        """
         c_symmetry = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutNodeSymmetryGet(
             self.hdwf,
@@ -461,7 +599,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return symmetry
 
     def nodePhaseInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get node phase info, in degrees."""
+        """Get node phase info, in degrees.
+        """
         c_phase_min = typespec_ctypes.c_double()
         c_phase_max = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutNodePhaseInfo(
@@ -477,7 +616,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return (phase_min, phase_max)
 
     def nodePhaseSet(self, channel_index: int, node: DwfAnalogOutNode, phase: float) -> None:
-        """Set node phase, in degrees."""
+        """Set node phase, in degrees.
+        """
         result = self.lib.FDwfAnalogOutNodePhaseSet(
             self.hdwf,
             channel_index,
@@ -487,7 +627,8 @@ class AnalogOut(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def nodePhaseGet(self, channel_index: int, node: DwfAnalogOutNode) -> float:
-        """Get node phase, in degrees."""
+        """Get node phase, in degrees.
+        """
         c_phase = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogOutNodePhaseGet(
             self.hdwf,
@@ -499,8 +640,15 @@ class AnalogOut(DwfDevice_SubAPI):
         phase = c_phase.value
         return phase
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                                NODE DATA MANAGEMENT                                              #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def nodeDataInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get node data info, in samples."""
+        """Get node data info, in samples.
+        """
         c_samples_min = typespec_ctypes.c_int()
         c_samples_max = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogOutNodeDataInfo(
@@ -516,7 +664,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return (samples_min, samples_max)
 
     def nodeDataSet(self, channel_index: int, node: DwfAnalogOutNode, data: np.ndarray) -> None:
-        """Set node data."""
+        """Set node data.
+        """
 
         double_data = data.astype(np.float64)
 
@@ -529,44 +678,9 @@ class AnalogOut(DwfDevice_SubAPI):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def customAMFMEnableSet(self, channel_index: int, enable: bool) -> None:
-        """Set custom AM/FM enable status."""
-        result = self.lib.FDwfAnalogOutCustomAMFMEnableSet(self.hdwf, channel_index, int(enable))
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def customAMFMEnableGet(self, channel_index: int) -> bool:
-        """Get custom AM/FM enable status."""
-        c_enable = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogOutCustomAMFMEnableGet(self.hdwf, channel_index, c_enable)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        enable = bool(c_enable.value)
-        return enable
-
-    def reset(self, channel_index: int) -> None:
-        """Reset the AnalogOut instrument."""
-        result = self.lib.FDwfAnalogOutReset(self.hdwf, channel_index)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def configure(self, channel_index: int, start: bool) -> None:
-        """Configure the AnalogOut instrument."""
-        result = self.lib.FDwfAnalogOutConfigure(self.hdwf, channel_index, start)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def status(self, channel_index: int) -> DwfState:
-        """Get AnalogOut instrument state."""
-        c_status = typespec_ctypes.DwfState()
-        result = self.lib.FDwfAnalogOutStatus(self.hdwf, channel_index, c_status)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        status = DwfState(c_status.value)
-        return status
-
     def nodePlayStatus(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[int, int, int]:
-        """Get node play status."""
+        """Get node play status.
+        """
         c_data_free = typespec_ctypes.c_int()
         c_data_lost = typespec_ctypes.c_int()
         c_data_corrupted = typespec_ctypes.c_int()
@@ -585,7 +699,8 @@ class AnalogOut(DwfDevice_SubAPI):
         return (data_free, data_lost, data_corrupted)
 
     def nodePlayData(self, channel_index: int, node: DwfAnalogOutNode, data: np.ndarray) -> None:
-        """Configure node play data."""
+        """Configure node play data.
+        """
         result = self.lib.FDwfAnalogOutNodePlayData(
             self.hdwf,
             channel_index,
@@ -595,21 +710,11 @@ class AnalogOut(DwfDevice_SubAPI):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    # The 25 methods that wrap obsolete functions follow:
-
-    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
-        """Get analog out trigger source info.
-
-        This function is OBSOLETE.
-        """
-        c_trigger_source_info_bitset = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogOutTriggerSourceInfo(self.hdwf, c_trigger_source_info_bitset)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        trigger_source_info_bitset = c_trigger_source_info_bitset.value
-        trigger_source_info_list = [trigger_source for trigger_source in DwfTriggerSource
-                                    if trigger_source_info_bitset & (1 << trigger_source.value)]
-        return trigger_source_info_list
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                            CARRIER CONFIGURATION (OBSOLETE)                                      #
+    #                                                                                                                  #
+    ####################################################################################################################
 
     def enableSet(self, channel_index: int, enable: bool) -> None:
         """Enable or disable the specified AnalogOut channel.
@@ -842,6 +947,12 @@ class AnalogOut(DwfDevice_SubAPI):
         phase = c_phase.value
         return phase
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                          CARRIER DATA MANAGEMENT (OBSOLETE)                                      #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def dataInfo(self, channel_index: int):
         """Get data buffer info.
 
@@ -896,9 +1007,7 @@ class AnalogOut(DwfDevice_SubAPI):
     def playData(self, channel_index: int, data: np.ndarray) -> None:
         """Play data.
 
-        This function is OBSOLETE.
-
-        (Add link to replacement.)
+        This function is OBSOLETE. Use `nodePlayData` instead.
         """
 
         double_data = data.astype(np.float64)
