@@ -2,14 +2,14 @@
 
 from typing import Optional
 
+from pydwf.core.dwf_library_subapi import DwfLibrarySubApi
+
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
-
 from pydwf.core.dwf_device import DwfDevice
-from pydwf.core.api.sub_api import DwfLibrary_SubAPI
 
 
-class DeviceControl(DwfLibrary_SubAPI):
+class DeviceControl(DwfLibrarySubApi):
     """The |DeviceControl| class provides access to the device control functionality of a
     |DwfLibrary:link|.
 
