@@ -3,14 +3,15 @@
 import ctypes
 from typing import Optional, Tuple, Union
 
+from pydwf.core.dwf_library_subapi import DwfLibrarySubApi
+
 from pydwf.core.auxiliary.enum_types import DwfEnumFilter, DwfEnumConfigInfo
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.exceptions import PyDwfError
-from pydwf.core.api.sub_api import DwfLibrary_SubAPI
 
 
-class DeviceEnumeration(DwfLibrary_SubAPI):
+class DeviceEnumeration(DwfLibrarySubApi):
     """The |DeviceEnumeration| class provides access to the device enumeration functionality of a
     |DwfLibrary:link|.
 
