@@ -3,13 +3,14 @@
 from typing import Tuple
 import ctypes
 
+from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.exceptions import PyDwfError
-from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
-class DigitalCan(DwfDevice_SubAPI):
+class DigitalCan(DwfDeviceSubApi):
     """The |DigitalCan| class provides access to the CAN bus protocol functionality of a |DwfDevice:link|.
 
     Attention:
