@@ -2,12 +2,13 @@
 
 from typing import List, Tuple
 
+from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
-from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
-class DigitalI2c(DwfDevice_SubAPI):
+class DigitalI2c(DwfDeviceSubApi):
     """The |DigitalI2c| class provides access to the I²C protocol functionality of a |DwfDevice:link|.
 
     Attention:
