@@ -4,14 +4,15 @@ from typing import List, Tuple
 
 import numpy as np
 
+from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+
 from pydwf.core.auxiliary.enum_types import (DwfDigitalInSampleMode, DwfDigitalInClockSource,
                                              DwfAcquisitionMode, DwfTriggerSlope, DwfState, DwfTriggerSource)
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
-from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
-class DigitalIn(DwfDevice_SubAPI):
+class DigitalIn(DwfDeviceSubApi):
     """The |DigitalIn| class provides access to the DigitalIn (logic analyzer) instrument of a |DwfDevice:link|.
 
     Attention:
