@@ -1,11 +1,12 @@
 """The |pydwf.core.api.digital_io| module implements a single class: |DigitalIO|."""
 
+from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
-from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
-class DigitalIO(DwfDevice_SubAPI):
+class DigitalIO(DwfDeviceSubApi):
     """The |DigitalIO| class provides access to the digital I/O functionality of a |DwfDevice:link|.
 
     Attention:
