@@ -2,15 +2,16 @@
 
 from typing import Tuple, List
 
+from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.enum_types import (DwfTriggerSource, DwfTriggerSlope, DwfDigitalOutOutput, DwfDigitalOutType,
                                              DwfState, DwfDigitalOutIdle)
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.exceptions import PyDwfError
-from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
-class DigitalOut(DwfDevice_SubAPI):
+class DigitalOut(DwfDeviceSubApi):
     """The |DigitalOut| class provides access to the DigitalOut (pattern generator) instrument of a |DwfDevice:link|.
 
     Attention:
