@@ -2,13 +2,14 @@
 
 from typing import List
 
+from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.enum_types import DwfDigitalOutIdle
-from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
-class DigitalSpi(DwfDevice_SubAPI):
+class DigitalSpi(DwfDeviceSubApi):
     """The |DigitalSpi| class provides access to the SPI protocol functionality of a |DwfDevice:link|.
 
     Attention:
