@@ -3,12 +3,13 @@
 import ctypes
 from typing import Tuple
 
+from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
-from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
-class DigitalUart(DwfDevice_SubAPI):
+class DigitalUart(DwfDeviceSubApi):
     """The |DigitalUart| class provides access to the UART protocol functionality of a |DwfDevice:link|.
 
     Attention:
