@@ -1,4 +1,4 @@
-"""Python equivalents of the enum types found in the C library header file *dwf.h*.
+"""This module defines Python equivalents of the enum types found in the C library header file *dwf.h*.
 
 Note:
     The obsolete enum types *TRIGCOND* and *STS* that are defined in the C header file have not been defined here.
@@ -10,10 +10,10 @@ import enum
 
 @enum.unique
 class DwfEnumFilter(enum.Enum):
-    """Device enumeration filter constants.
+    """Enumeration type for device class constants, used during device enumeration.
 
-    This type is used exclusively by the |DwfLibrary.deviceEnum.enumerateDevices:link| method to constrain
-    the type of devices that will be found during device enumeration.
+    This type is used by the |DwfLibrary.deviceEnum.enumerateDevices:link| method to constrain
+    the type of devices that will be considered during device enumeration.
 
     In the C API, this type is called 'ENUMFILTER', and it is represented as an *int*.
     """
@@ -36,9 +36,9 @@ class DwfEnumFilter(enum.Enum):
 
 @enum.unique
 class DwfDeviceID(enum.Enum):
-    """Device ID constants.
+    """Enumeration type for device ID constants.
 
-    This type is used exclusively by the |DwfLibrary.deviceEnum.deviceType:link| method to report on a selected device.
+    This type is used by the |DwfLibrary.deviceEnum.deviceType:link| method to report on a selected device.
 
     In the C API, this type is called 'DEVID', and it is represented as an *int*.
     """
@@ -60,9 +60,10 @@ class DwfDeviceID(enum.Enum):
 
 
 class DwfDeviceVersion(enum.Enum):
-    """Device versions (revisions).
+    """Enumeration type for device version (i.e., hardware revision) constants.
 
-    This type is used exclusively by the |DwfLibrary.deviceEnum.deviceType:link| method to report on a selected device.
+    This type is used by the |DwfLibrary.deviceEnum.deviceType:link| method to report the
+    hardware revision of a selected device.
 
     Note:
         The device revision list given here is not complete; it does not cover all devices.
@@ -89,7 +90,7 @@ class DwfDeviceVersion(enum.Enum):
 
 @enum.unique
 class DwfTriggerSource(enum.Enum):
-    """Trigger source.
+    """Enumeration type for trigger source constants.
 
     This type is used by the |DeviceControl| functionality and by the |AnalogIn|, |AnalogOut|, |DigitalIn|,
     and |DigitalOut| instruments.
@@ -101,7 +102,7 @@ class DwfTriggerSource(enum.Enum):
     """No trigger configured (device starts immediately)."""
 
     PC = 1
-    """PC trigger."""
+    """PC (software) trigger."""
 
     DetectorAnalogIn  = 2
     """AnalogIn trigger detector."""
@@ -131,16 +132,16 @@ class DwfTriggerSource(enum.Enum):
     """AnalogOut instrument channel 4 start."""
 
     External1 = 11
-    """External trigger #1"""
+    """External trigger #1."""
 
     External2 = 12
-    """External trigger #2"""
+    """External trigger #2."""
 
     External3 = 13
-    """External trigger #3"""
+    """External trigger #3."""
 
     External4 = 14
-    """External trigger #4"""
+    """External trigger #4."""
 
     High = 15
     """High (undocumented)."""
@@ -150,15 +151,18 @@ class DwfTriggerSource(enum.Enum):
 
 
 class DwfState(enum.Enum):
-    """Instrument states, for the instruments that are controlled by an internal state-machine:
+    """Enumeration type for instrument state constants, for instruments that are controlled by an internal
+    state-machine.
 
-    * AnalogIn
-    * AnalogOut
-    * DigitalIn
-    * DigitalOut
-    * AnalogImpedance
+    The following instrument APIs are controlled by a state machine:
 
-    Specifically, this type is used to return the state from a *status()* method.
+    * |AnalogIn|
+    * |AnalogOut|
+    * |DigitalIn|
+    * |DigitalOut|
+    * |AnalogImpedance|
+
+    This type is used to return the current state from their *status()* methods.
 
     Note:
         The enumeration values :py:attr:`Triggered` and :py:attr:`Running` have identical integer values (3).
@@ -196,12 +200,24 @@ class DwfState(enum.Enum):
 
 @enum.unique
 class DwfEnumConfigInfo(enum.Enum):
-    """Enum configuration info.
+    """Enumeration type for configuration parameter type constants.
 
-    This type describes device parameters that vary between device configurations.
+    This type lists the device parameters that can vary between different configurations
+    of the same device.
 
-    This type is used exclusively by the |DwfLibrary.deviceEnum.configInfo:link| method to report the capabilities
-    of the different configurations of a selected device.
+    For some Digilent Waveforms devices, multiple firmware configurations are available that make
+    different tradeoffs for certain hard-coded parameters.
+
+    For example, one configuration may support a lot of buffering memory for the |AnalogIn| instrument,
+    while another configuration may support a lot of buffering memory for the |DigitalOut| instrument.
+
+    The user can specify which device configuration to use when opening the device; the configuration
+    is then fixed during use, until the device is closed.
+
+    For many use cases, the default configuration that provides a balanced tradeoff works fine. User
+    programs that need more control can use the |DwfLibrary.deviceEnum.configInfo:link| method during
+    device enumeration to inspect the different configurations available, and use the information
+    obtained to pick the best configuration.
 
     In the C API, this type is represented as an *int*.
     """
@@ -264,9 +280,11 @@ class DwfEnumConfigInfo(enum.Enum):
 
 @enum.unique
 class DwfAcquisitionMode(enum.Enum):
-    """Acquisition mode.
+    """Enumeration type for acquisition mode constants.
 
-    This type is used by the |AnalogIn| and |DigitalIn| instruments.
+    This type is used by the |AnalogIn| and |DigitalIn| instruments. These instruments
+    support multiple acquisition modes that are appropriate for different data
+    acquisition tasks.
 
     In the C API, this type is called 'ACQMODE', and it is represented as an *int*.
     """
@@ -275,17 +293,18 @@ class DwfAcquisitionMode(enum.Enum):
     """Perform a single buffer acquisition.
 
     Re-arm the instrument for the next capture after the data is fetched to the host
-    using the `status` function.
+    using the *status()* method.
 
-    The difference with the :py:attr:`Single` mode is unclear.
+    Note:
+        The difference with the :py:attr:`Single` mode is unclear.
     """
 
     ScanShift = 1
     """Perform a continuous acquisition in FIFO style.
 
     The trigger setting is ignored. The last sample is at the end of the buffer.
-    The *statusSamplesValid* method shows the number of the acquired samples,
-    which will grow until reaching the buffer size.
+    The *statusSamplesValid()* method shows the number of the acquired samples,
+    which will increase until reaching the buffer size.
     After that, the waveform image is shifted for every new sample.
     """
 
@@ -296,11 +315,11 @@ class DwfAcquisitionMode(enum.Enum):
 
     The trigger setting is ignored.
 
-    The *statusIndexWrite* value shows the buffer write position.
+    The *statusIndexWrite()* value shows the buffer write position.
     """
 
     Record = 3
-    """Perform acquisition for the length of time set by *recordLengthSet* method."""
+    """Perform acquisition for the length of time set by *recordLengthSet()* method."""
 
     Overs = 4
     """Overscan mode (undocumented)."""
@@ -308,16 +327,30 @@ class DwfAcquisitionMode(enum.Enum):
     Single1 = 5
     """Perform a single buffer acquisition.
 
-    The difference with the :py:attr:`Single` mode is unclear.
+    Note:
+        The difference with the :py:attr:`Single` mode is unclear.
     """
 
 
 @enum.unique
 class DwfAnalogInFilter(enum.Enum):
-    """Analog acquisition filter.
+    """Enumeration type for analog input filter constants.
 
-    This type is used exclusively in the |AnalogIn| instrument to specify a filtering algorithm for the input-
-    and trigger-channels.
+    This type is used by the |AnalogIn| instrument to select a filtering algorithm for the input and trigger channels.
+
+    The |AnalogIn| instrument's ADC always captures samples at the maximum possible rate. If data acquisition at
+    a lower sampling rate is requested, the resampling can be handled it several different ways.
+
+    The most obvious choice is *averaging*. This will suppress high-frequency noise, which is often a good thing,
+    but often it is also desirable to know that high-frequency noise is present in the signal, and the averaging
+    may hide that fact.
+
+    For that reason, the *decimation* filter is available, which simply selects a single sample captured at high
+    frequency when resampling to a lower frequency. The signal-to-noise ratio (SNR) will suffer, but the presence
+    of high-frequency noise (outliers) will be more easily seen in the resampled data.
+
+    Todo:
+        Examine the MinMax filter choice; it is not currently understood.
 
     In the C API, this type is called 'FILTER", and it is represented as an *int*.
     """
@@ -334,9 +367,9 @@ class DwfAnalogInFilter(enum.Enum):
 
 @enum.unique
 class DwfTriggerType(enum.Enum):
-    """Analog in trigger mode.
+    """Enumeration type for analog input trigger mode constants.
 
-    This type is used exclusively in the |AnalogIn| instrument to specify the trigger type.
+    This type is used by the |AnalogIn| instrument to specify the trigger type.
 
     In the C API, this type is called 'TRIGTYPE', and it is represented as an *int*.
     """
@@ -356,7 +389,7 @@ class DwfTriggerType(enum.Enum):
 
 @enum.unique
 class DwfTriggerSlope(enum.Enum):
-    """Trigger slope.
+    """Enumeration type for trigger slope constants.
 
     This type is used by the |AnalogIn|, |AnalogOut|, |DigitalIn|, and |DigitalOut| instruments to select
     the trigger slope.
@@ -366,14 +399,6 @@ class DwfTriggerSlope(enum.Enum):
     In the C API, this type is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfTriggerSlope.valueName".
-        """
-        return "DwfTriggerSlope." + self.name
-
     Rise = 0
     """Rising trigger slope."""
 
@@ -386,7 +411,7 @@ class DwfTriggerSlope(enum.Enum):
 
 @enum.unique
 class DwfTriggerLengthCondition(enum.Enum):
-    """Analog in trigger length condition.
+    """Enumeration type for analog input trigger length condition constants.
 
     This type is used by the |AnalogIn| instrument to specify the trigger length condition.
 
@@ -405,7 +430,7 @@ class DwfTriggerLengthCondition(enum.Enum):
 
 @enum.unique
 class DwfErrorCode(enum.Enum):
-    """Error codes for the DWF public API.
+    """Enumeration type for error reporting constants of the DWF API.
 
     This type is used by the |DwfLibrary.getLastError:link| method to report the error condition of the most
     recent C API call.
@@ -423,7 +448,7 @@ class DwfErrorCode(enum.Enum):
     """Unknown error."""
 
     ApiLockTimeout = 2
-    """API waiting on pending API timed out."""
+    """API waiting on pending operation timed out."""
 
     AlreadyOpened = 3
     """Device already opened."""
@@ -449,175 +474,233 @@ class DwfErrorCode(enum.Enum):
 
 @enum.unique
 class DwfAnalogOutFunction(enum.Enum):
-    """Analog out waveform function types.
+    """Enumeration type for analog output waveform-shape function constants.
 
-    This type is used exclusively by the |AnalogOut| instrument to represent the wave-shape produced on an
+    This type is used by the |AnalogOut| instrument to represent the wave-shape produced on an
     analog output channel node.
 
     In the C API, this type is called 'FUNC', and it is represented as an *unsigned char*.
     """
 
-    DC        = 0
-    Sine      = 1
-    Square    = 2
-    Triangle  = 3
-    RampUp    = 4
-    RampDown  = 5
-    Noise     = 6
-    Pulse     = 7
+    DC = 0
+    """DC (constant signal) waveform shape. The signal level varies between -1 and 1."""
+
+    Sine = 1
+    """Sinusoid waveform shape. The signal level varies between -1 and 1."""
+
+    Square = 2
+    """Square waveform shape. The signal level varies between -1 and 1."""
+
+    Triangle = 3
+    """Triangle waveform shape. The signal level varies between -1 and 1."""
+
+    RampUp = 4
+    """Ramp Up waveform shape. The signal level varies between -1 and 1."""
+
+    RampDown = 5
+    """Ramp Down waveform shape. The signal level varies between -1 and 1."""
+
+    Noise = 6
+    """Noise waveform shape. The signal level is uniformly distributed between -1 and 1."""
+
+    Pulse = 7
+    """Pulse waveform shape. The signal level varies between 0 and 1."""
+
     Trapezium = 8
+    """Trapezium waveform shape. The signal level varies between -1 and 1."""
+
     SinePower = 9
-    Custom    = 30
-    Play      = 31
+    """Sinusoid Power waveform shape. The signal level varies between -1 and 1."""
+
+    Custom = 30
+    """Custom (user-defined) waveform shape. The signal level varies between -1 and 1."""
+
+    Play = 31
+    """Continuous playback mode. The signal level varies between -1 and 1."""
 
 
 @enum.unique
 class DwfAnalogIO(enum.Enum):
-    """Analog I/O channel node types.
+    """Enumeration type for Analog I/O channel node type constants.
 
-    This type is used exclusively by the |AnalogIO| functionality to report node information.
+    This type is used by the |AnalogIO| functionality to report the node type.
 
     In the C API, this type is called 'ANALOGIO', and it is represented as an *unsigned char*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
+    Enable = 1
+    """The node represent an on/off switch."""
 
-        Returns:
-            str: A string representation of the enum value, as "DwfAnalogIO.valueName".
-        """
-        return "DwfAnalogIO." + self.name
+    Voltage = 2
+    """The node represents a voltage."""
+
+    Current = 3
+    """The node represents a current."""
+
+    Power = 4
+    """The node represents a power."""
 
-    Enable      = 1
-    Voltage     = 2
-    Current     = 3
-    Power       = 4
     Temperature = 5
-    Dmm         = 6
-    Range       = 7
-    Measure     = 8
-    Time        = 9
-    Frequency   = 10
+    """The node represents a temperature."""
+
+    Dmm = 6
+    """(unknown)"""
+
+    Range = 7
+    """The node represents a range."""
+
+    Measure = 8
+    """(unknown)"""
+
+    Time = 9
+    """The node represents a time."""
+
+    Frequency = 10
+    """The node represents a frequency."""
 
 
 @enum.unique
 class DwfAnalogOutNode(enum.Enum):
-    """Analog Out node type.
+    """Enumeration type for analog output node type constants.
 
-    This type is used exclusively by the |AnalogOut| instrument to represent one of the
-    nodes associated with each output channel.
+    This type is used by the |AnalogOut| instrument to represent the node types associated with each output channel.
 
     In the C API, this type is called 'AnalogOutNode' (without the *Dwf* prefix), and it is represented as an *int*.
     """
 
     Carrier = 0
-    FM      = 1
-    AM      = 2
+    """Carrier signal node."""
+
+    FM = 1
+    """Frequency Modulation node."""
+
+    AM = 2
+    """Amplitude Modulation node."""
 
 
 @enum.unique
 class DwfAnalogOutMode(enum.Enum):
-    """Analog Out mode (voltage or current).
+    """Enumeration type for analog out mode constants (voltage or current).
 
-    This type is used exclusively by the |AnalogOut| instrument to set or retrieve to
-    mode of a channel.
+    This type is used by the |AnalogOut| instrument to set or retrieve the mode of a channel.
 
     In the C API, this type is represented as an *int*.
     """
 
     Voltage = 0
+    """Voltage mode."""
+
     Current = 1
+    "Current mode."""
 
 
 @enum.unique
 class DwfAnalogOutIdle(enum.Enum):
-    """Analog Out idle state.
+    """Enumeration type for analog output idle state constants.
 
-    This type is used exclusively by the |AnalogOut| instrument to set the idle behavior
-    of an output channel.
+    This type is used by the |AnalogOut| instrument to set the idle behavior of an output channel.
 
     In the C API, this type is represented as an *int*.
     """
 
-    Disable  = 0
-    Offset   = 1
-    Initial  = 2
+    Disable = 0
+    """When idle, disable the output."""
+
+    Offset = 1
+    """When idle, drive the analog output offset."""
+
+    Initial = 2
+    """When idle, drive the initial value of the selected waveform shape."""
 
 
 @enum.unique
 class DwfDigitalInClockSource(enum.Enum):
-    """Digital In clock source.
+    """Enumeration type for digital input clock source constants.
 
-    This type is used exclusively by the |DigitalIn| instrument to specify a clock source.
+    This type is used by the |DigitalIn| instrument to specify a clock source.
 
     In the C API, this type is represented as an *int*.
     """
 
-    Internal  = 0
-    External  = 1
+    Internal = 0
+    """Use internal clock source."""
+
+    External = 1
+    """Use external clock source."""
+
     External2 = 2
+    """Use alternate external clock source."""
 
 
 @enum.unique
 class DwfDigitalInSampleMode(enum.Enum):
-    """Digital In sample mode.
+    """Enumeration type for digital input sample mode constants.
 
-    This type is used exclusively by the |DigitalIn| instrument to specify a sample mode.
+    This type is used by the |DigitalIn| instrument to specify a sample mode.
 
     In the C API, this type is represented as an *int*.
     """
 
     Simple = 0
-    """
-    Only digital samples (no noise).
-    """
+    """Only digital samples (no noise)."""
+
     Noise  = 1
-    """
-    Alternate samples: (noise, sample, noise, sample, …) where noise is more than 1 transition between 2 samples.
-    """
+    """Alternate samples: (noise, sample, noise, sample, …) where noise is more than 1 transition between 2 samples."""
 
 
 @enum.unique
 class DwfDigitalOutOutput(enum.Enum):
-    """Digital Out output mode.
+    """Enumeration type for digital output mode constants.
 
-    This type is used exclusively by the |DigitalOut| instrument to specify the electronic behavior of a digital
-    output channel.
+    This type is used by the |DigitalOut| instrument to specify the electronic behavior of a digital output channel.
 
     In the C API, this type is represented as an *int*.
     """
 
-    PushPull   = 0
+    PushPull = 0
     """Push/Pull"""
-    OpenDrain  = 1
+
+    OpenDrain = 1
     """Open Drain"""
+
     OpenSource = 2
     """Open Source"""
+
     ThreeState = 3
     """Tristate (for custom and random)"""
 
 
 @enum.unique
 class DwfDigitalOutType(enum.Enum):
-    """Digital Out type.
+    """Enumeration type for digital output type constants.
 
-    This type is used exclusively by the |DigitalOut| instrument to specify the behavior mode of a digital
-    output channel.
+    This type is used by the |DigitalOut| instrument to specify the behavior mode of a digital output channel.
 
     In the C API, this type is represented as an *int*.
     """
 
-    Pulse  = 0
+    Pulse = 0
+    """Pulse output."""
+
     Custom = 1
+    """Custom output."""
+
     Random = 2
-    ROM    = 3
-    State  = 4
-    Play   = 5
+    """Random output."""
+
+    ROM = 3
+    """ROM (lookup table) output."""
+
+    State = 4
+    """State machine output."""
+
+    Play = 5
+    """Continuous playback output."""
 
 
 @enum.unique
 class DwfDigitalOutIdle(enum.Enum):
-    """Digital Out idle mode.
+    """Enumeration type for digital output idle mode constants.
 
     This type is used primarily by the |DigitalOut| instrument to specify the idle behavior mode of a digital
     output channel.
@@ -643,35 +726,66 @@ class DwfDigitalOutIdle(enum.Enum):
 
 @enum.unique
 class DwfAnalogImpedance(enum.Enum):
-    """Analog Impedance measurement setting.
+    """Enumeration type for analog impedance measurement types.
 
-    This type is used exclusively by the |AnalogImpedance| measurement functionality to specify a measurement type.
+    This type is used by the |AnalogImpedance| measurement functionality to specify a measurement quantity type.
 
     In the C API, this type is represented as an *int*.
     """
 
-    Impedance           =  0  # Ohms
-    ImpedancePhase      =  1  # Radians
-    Resistance          =  2  # Ohms
-    Reactance           =  3  # Ohms
-    Admittance          =  4  # Siemens
-    AdmittancePhase     =  5  # Radians
-    Conductance         =  6  # Siemens
-    Susceptance         =  7  # Siemens
-    SeriesCapacitance   =  8  # Farad
-    ParallelCapacitance =  9  # Farad
-    SeriesInductance    = 10  # Henry
-    ParallelInductance  = 11  # Henry
-    Dissipation         = 12  # factor
-    Quality             = 13  # factor
+    Impedance = 0
+    """Measure impedance, in Ohms."""
+
+    ImpedancePhase = 1
+    """Measure impedance phase, in radians."""
+
+    Resistance = 2
+    """Measure resistance, in Ohms."""
+
+    Reactance = 3
+    """Measure reactance, in Ohms."""
+
+    Admittance = 4
+    """Measure admittance, in Siemens."""
+
+    AdmittancePhase = 5
+    """Measure admittance phase, in radians."""
+
+    Conductance = 6
+    """Measure conductance, in Siemens."""
+
+    Susceptance = 7
+    """Measure susceptance, in Siemens."""
+
+    SeriesCapacitance = 8
+    """Measure series capacitance, in Farad."""
+
+    ParallelCapacitance = 9
+    """Measure parallel capacitance, in Farad."""
+
+    SeriesInductance = 10
+    """Measure series inductance, in Henry."""
+
+    ParallelInductance = 11
+    """Measure parallel inductance, in Henry."""
+
+    Dissipation = 12
+    """Measure dissipation, as a factor."""
+
+    Quality = 13
+    """Measure quality, as a factor."""
 
 
 @enum.unique
 class DwfParameter(enum.Enum):
-    """Device parameter selection.
+    """Enumeration type for device parameter constants.
 
-    This type is used to select device parameters, either to set/get global defaults (|DwfLibrary|)
-    or to set/get parameters on a specific, open device (|DwfDevice|).
+    Device parameters are miscellaneous integer settings that influence the behavior of a device.
+
+    The different device parameters are selected by one of the constant values defined here.
+
+    This type is used to select device parameters, either to set/get global defaults using the |DwfLibrary|, or to
+    to set/get parameter values on a specific, previously opened device |DwfDevice|.
 
     In the C API, this type is called 'DwfParam', and it is represented as an *int*.
     """
@@ -740,7 +854,8 @@ class DwfParameter(enum.Enum):
     Frequency = 8
     """This parameter is undocumented.
 
-    The function of this parameter needs to be ascertained.
+    Todo:
+        The meaning of this parameter needs to be understood.
 
-    It is some frequency, expressed in MHz.
+        It is some frequency, expressed in MHz.
     """
