@@ -57,8 +57,8 @@ class DwfLibrary:
                 a mismatch, an exception will be raised.
 
         Raises:
-            PyDwfError: The version check could not be performed do to an unexpected low-level error while querying the
-                shared library version; or a version mismatch was detected.
+            PyDwfError: The version check could not be performed due to an unexpected low-level error while querying
+                the shared library version; or a version mismatch was detected.
         """
 
         if sys.platform.startswith("win"):
@@ -214,8 +214,8 @@ class DwfLibrary:
     def paramSet(self, parameter: DwfParameter, value: int) -> None:
         """Configure a default parameter value.
 
-        Parameters are settings of a specific |DwfDevice|.
-        Different |DwfDevice| instances can have different values for each of the possible |DwfParameter| parameters.
+        Parameters are settings of a specific |DwfDevice|. Different |DwfDevice| instances
+        can have different values for each of the possible |DwfParameter:link| parameters.
 
         This method sets parameter values at the library level.
         They are used as default parameters for devices that are opened subsequently.
@@ -238,8 +238,8 @@ class DwfLibrary:
     def paramGet(self, parameter: DwfParameter) -> int:
         """Return a default parameter value.
 
-        Parameters are settings of a specific |DwfDevice|.
-        Different |DwfDevice| instances can have different values for each of the possible |DwfParameter| parameters.
+        Parameters are settings of a specific |DwfDevice|. Different |DwfDevice| instances
+        can have different values for each of the possible |DwfParameter:link| parameters.
 
         This method retrieves parameter values at the library level.
         They are used as default parameters for devices that are opened subsequently.
