@@ -8,71 +8,85 @@ from pydwf.core.auxiliary.enum_types import DwfEnumConfigInfo, DwfEnumFilter
 from pydwf.core.auxiliary.exceptions import PyDwfError
 
 
-def open_dwf_device(dwf: DwfLibrary,
-                    enum_filter: Optional[DwfEnumFilter] = None,
-                    serial_number: Optional[str] = None,
-                    configuration_fitness_func: Optional[Callable[[Dict[str, Any]], Optional[int]]] = None
-                    ) -> DwfDevice:
+def open_dwf_device(
+            dwf: DwfLibrary,
+            enum_filter: Optional[DwfEnumFilter] = None,
+            serial_number: Optional[str] = None,
+            configuration_fitness_func: Optional[Callable[[Dict[DwfEnumConfigInfo, Any]], Optional[int]]] = None
+        ) -> DwfDevice:
     """Open a device identified by its serial number, optionally selecting a preferred configuration.
 
     This is a three-step process:
 
     1. The first step this function performs is to select a device for opening.
 
-       To do this, all available Digilent Waveforms devices are enumerated. For this initial enumeration process
-       the *enum_filter* parameter is used, if given.
+       To do this, device enumeration is performed, resulting in a list of all reachable Digilent Waveforms devices.
+
+       For this initial enumeration process the *enum_filter* can be used to only list certain types of devices
+       (for example, only Analog Discovery 2 devices, or Dgitial Discovery devices). If omitted (the default),
+       all Digilent Waveforms devices will be listed.
 
        Then, if the *serial_number* parameter is given, the list will be filtered to exclude devices whose serial
        numbers do not match.
 
        If the list that remains has a single device, this device will be used. If not, a |PyDwfError| is reported.
 
-    2. The next step is to select a configuration for the device.
+    2. The next step is to select a *device configuration* for the selected device.
 
-       If no *configuration_fitness_func* is provided, the first (default) configuration will be used.
+       For some Digilent Waveforms devices, multiple firmware configurations are available that make
+       different tradeoffs for certain hard-coded parameters.
 
-       If a *configuration_fitness_func* is provided, it should be a function (or lambda expression) that takes a
-       single parameter *configuration_info*, which is a dictionary with string keys that correspond to the names
-       of each possible |DwfEnumConfigInfo:link| entry, and values that correspond to the value of that parameter
-       for a specific configuration.
+       For example, one configuration may support a lot of buffering memory for the |AnalogIn| instrument,
+       while another configuration may support a lot of buffering memory for the |DigitalOut| instrument.
 
-       The function should return *None* if the configuration is entirely unsuitable, or otherwise an integer score
-       that reflects the 'desirability' or 'fitness' score of that particular configuration for the task at hand.
+       For many use cases, the default configuration that provides a balanced tradeoff works fine.
+       If no *configuration_fitness_func* is provided, this default configuration will be used.
+
+       If a *configuration_fitness_func* is provided, it should be a function (or lambda expression) that
+       takes a single parameter *configuration_info*, which is a dictionary with |DwfEnumConfigInfo:link| keys,
+       and parameters values for a specific device configuration.
+
+       The function should return *None* if the configuration is entirely unsuitable, or otherwise a score
+       that reflects the 'desirability' or 'fitness' of that particular configuration for the task at hand.
 
        The *open_dwf_device* function will go through all available device configurations, construct a dictionary
        of all parameters that describe the configuration, call the *configuration_fitness_func* with that dictionary,
        and examine the score value it returns. If multiple suitable device configurations are found (i.e., the
        *configuration_fitness_func* does not return None), it will select the configuration with the highest score.
 
-       This may all sounds pretty complicated, but in practice this parameter is quite easy to define for most common
-       use-cases.
+       This may all sounds pretty complicated, but in practice this parameter is quite easy to define for most
+       common use-cases.
 
        As an example, to select a configuration that maximizes the analog input buffer size, simply use this:
 
        .. code-block:: python
 
-          def fitness_func(config_parameters):
-              return config_parameters["AnalogInBufferSize"]
+          from pydwf import DwfEnumConfigInfo
+          from pydwf.utilities import open_dwf_device
 
-          with open_dwf_device(dwf, configuration_fitness_func = fitness_func) as device:
+          def maximize_analog_in_buffer_size(config_parameters):
+              return config_parameters[DwfEnumConfigInfo.AnalogInBufferSize]
+
+          with open_dwf_device(dwf,
+                    configuration_fitness_func = maximize_analog_in_buffer_size) as device:
               use_device_with_big_analog_in_buffer(device)
 
-    3. As a final step, the selected device is opened using the selected device configuration, and the |DwfDevice:link|
-       instance is returned.
+    3. As a final step, the selected device is opened using the selected device configuration, and the
+       newly instantiated |DwfDevice:link| instance is returned.
 
     Note:
         This method takes several seconds to complete.
 
     Parameters:
         dwf (DwfLibrary): The |DwfLibrary:link| used to open the device.
-        serial_number (str): The serial number of the device to be opened.
-            Digilent Waveforms device serial numbers consist of 12 hexadecimal digits.
-        configuration_fitness_func (Optional[Callable[[Dict[str, Any]]):
-            A function to score the preferred configuration of the selected device.
-            See the description above for details.
         enum_filter (Optional[DwfEnumFilter]):
             An optional filter to limit the device enumeration to certain device types.
             In None, enumerate all devices.
+        serial_number (str): The serial number of the device to be opened.
+            Digilent Waveforms device serial numbers consist of 12 hexadecimal digits.
+        configuration_fitness_func (Optional[Callable[[Dict[DwfEnumConfigInfo, Any]]):
+            A function to score the configurations of the selected device.
+            See the description above for details.
 
     Returns:
         DwfDevice: The |DwfDevice:link| created as a result of this call.
@@ -123,7 +137,7 @@ def open_dwf_device(dwf: DwfLibrary,
     device_index = candidate_devices[0]
 
     if configuration_fitness_func is None:
-        # If no 'configuration_fitness_func' was specified, just return the first one.
+        # If no 'configuration_fitness_func' was specified, just open the first (default) one.
         return dwf.deviceControl.open(device_index)
 
     # The caller specified a 'configuration_fitness_func'.
@@ -137,9 +151,9 @@ def open_dwf_device(dwf: DwfLibrary,
     for configuration_index in range(num_config):
 
         configuration_info = {
-            configuration_parameter.name:
-                dwf.deviceEnum.configInfo(configuration_index, configuration_parameter)
-            for configuration_parameter in DwfEnumConfigInfo}
+            configuration_parameter: dwf.deviceEnum.configInfo(configuration_index, configuration_parameter)
+                for configuration_parameter in DwfEnumConfigInfo
+        }
 
         configuration_fitness = configuration_fitness_func(configuration_info)
 
